#
# Copyright (C) 2025 Masaryk University
#
# DAR-CLI is free software; you can redistribute it and/or
# modify it under the terms of the MIT License; see LICENSE file for more
# details.


from setuptools import setup

setup()
